==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/nativemethods/NativeMethodNotSupportedException.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.NativeMethodNotSupportedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 2fdd159ffa8e3b5a soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *, struct _jc_soot_SootMethod$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs {
	struct _jc_java_lang_String$object	*msg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/nativemethods/NativeMethodNotSupportedException.h <==
// public class soot.jimple.toolkits.pointer.nativemethods.NativeMethodNotSupportedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 2fdd159ffa8e3b5a soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException_H_
#define _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$_init$5ff894e1e168ec0b(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vmethods	soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs {
	struct _jc_java_lang_String$object	*msg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs {
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_refs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$sub_nonrefs	soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$object {
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$vtype _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_nativemethods_NativeMethodNotSupportedException_H_ */
